package com.ruoyi.kaohe.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.kaohe.domain.KhType;
import com.ruoyi.kaohe.service.IKhTypeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 考核类型Controller
 * 
 * @author hs
 * @date 2025-06-17
 */
@RestController
@RequestMapping("/kaohe/type")
public class KhTypeController extends BaseController
{
    @Autowired
    private IKhTypeService khTypeService;

    /**
     * 查询考核类型列表
     */
    @PreAuthorize("@ss.hasPermi('kaohe:type:list')")
    @GetMapping("/list")
    public TableDataInfo list(KhType khType)
    {
        startPage();
        List<KhType> list = khTypeService.selectKhTypeList(khType);
        return getDataTable(list);
    }

    /**
     * 导出考核类型列表
     */
    @PreAuthorize("@ss.hasPermi('kaohe:type:export')")
    @Log(title = "考核类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, KhType khType)
    {
        List<KhType> list = khTypeService.selectKhTypeList(khType);
        ExcelUtil<KhType> util = new ExcelUtil<KhType>(KhType.class);
        util.exportExcel(response, list, "考核类型数据");
    }

    /**
     * 获取考核类型详细信息
     */
    @PreAuthorize("@ss.hasPermi('kaohe:type:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(khTypeService.selectKhTypeById(id));
    }

    /**
     * 新增考核类型
     */
    @PreAuthorize("@ss.hasPermi('kaohe:type:add')")
    @Log(title = "考核类型", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody KhType khType)
    {
        return toAjax(khTypeService.insertKhType(khType));
    }

    /**
     * 修改考核类型
     */
    @PreAuthorize("@ss.hasPermi('kaohe:type:edit')")
    @Log(title = "考核类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody KhType khType)
    {
        return toAjax(khTypeService.updateKhType(khType));
    }

    /**
     * 删除考核类型
     */
    @PreAuthorize("@ss.hasPermi('kaohe:type:remove')")
    @Log(title = "考核类型", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(khTypeService.deleteKhTypeByIds(ids));
    }
}
